==> zio-aws-sms_2.12-5.17.204.1-sources.jar: zio/aws/sms/model/package.scala <==
package zio.aws.sms
import zio.aws.sms.model.primitives.AppId
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sms.model.primitives.ValidationId.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmiId extends Subtype[String]
    type AmiId = zio.aws.sms.model.primitives.AmiId.Type
    object AppDescription extends Subtype[String]
    type AppDescription = zio.aws.sms.model.primitives.AppDescription.Type
    object AppId extends Subtype[String]
    type AppId = zio.aws.sms.model.primitives.AppId.Type
    object AppIdWithValidation extends Subtype[String]
    type AppIdWithValidation =
      zio.aws.sms.model.primitives.AppIdWithValidation.Type
    object AppLaunchStatusMessage extends Subtype[String]
    type AppLaunchStatusMessage =
      zio.aws.sms.model.primitives.AppLaunchStatusMessage.Type
    object AppName extends Subtype[String]
    type AppName = zio.aws.sms.model.primitives.AppName.Type
    object AppReplicationStatusMessage extends Subtype[String]
    type AppReplicationStatusMessage =
      zio.aws.sms.model.primitives.AppReplicationStatusMessage.Type
    object AppStatusMessage extends Subtype[String]
    type AppStatusMessage = zio.aws.sms.model.primitives.AppStatusMessage.Type
    object AssociatePublicIpAddress extends Subtype[Boolean]
    type AssociatePublicIpAddress =
      zio.aws.sms.model.primitives.AssociatePublicIpAddress.Type
    object AutoLaunch extends Subtype[Boolean]
    type AutoLaunch = zio.aws.sms.model.primitives.AutoLaunch.Type
    object BucketName extends Subtype[String]
    type BucketName = zio.aws.sms.model.primitives.BucketName.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.sms.model.primitives.ClientToken.Type
    object Command extends Subtype[String]
    type Command = zio.aws.sms.model.primitives.Command.Type
    object ConnectorId extends Subtype[String]
    type ConnectorId = zio.aws.sms.model.primitives.ConnectorId.Type
    object ConnectorVersion extends Subtype[String]
    type ConnectorVersion = zio.aws.sms.model.primitives.ConnectorVersion.Type
    object Description extends Subtype[String]
    type Description = zio.aws.sms.model.primitives.Description.Type
    object EC2KeyName extends Subtype[String]
    type EC2KeyName = zio.aws.sms.model.primitives.EC2KeyName.Type
    object Encrypted extends Subtype[Boolean]
    type Encrypted = zio.aws.sms.model.primitives.Encrypted.Type
    object ExecutionTimeoutSeconds extends Subtype[Int]
    type ExecutionTimeoutSeconds =
      zio.aws.sms.model.primitives.ExecutionTimeoutSeconds.Type
    object ForceStopAppReplication extends Subtype[Boolean]
    type ForceStopAppReplication =
      zio.aws.sms.model.primitives.ForceStopAppReplication.Type
    object ForceTerminateApp extends Subtype[Boolean]
    type ForceTerminateApp = zio.aws.sms.model.primitives.ForceTerminateApp.Type
    object Frequency extends Subtype[Int]
    type Frequency = zio.aws.sms.model.primitives.Frequency.Type
    object ImportedAppId extends Subtype[String]
    type ImportedAppId = zio.aws.sms.model.primitives.ImportedAppId.Type
    object InstanceId extends Subtype[String]
    type InstanceId = zio.aws.sms.model.primitives.InstanceId.Type
    object InstanceType extends Subtype[String]
    type InstanceType = zio.aws.sms.model.primitives.InstanceType.Type
    object IpAddress extends Subtype[String]
    type IpAddress = zio.aws.sms.model.primitives.IpAddress.Type
    object KmsKeyId extends Subtype[String]
    type KmsKeyId = zio.aws.sms.model.primitives.KmsKeyId.Type
    object LaunchOrder extends Subtype[Int]
    type LaunchOrder = zio.aws.sms.model.primitives.LaunchOrder.Type
    object LogicalId extends Subtype[String]
    type LogicalId = zio.aws.sms.model.primitives.LogicalId.Type
    object MacAddress extends Subtype[String]
    type MacAddress = zio.aws.sms.model.primitives.MacAddress.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.sms.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.sms.model.primitives.NextToken.Type
    object NonEmptyStringWithMaxLen255 extends Subtype[String]
    type NonEmptyStringWithMaxLen255 =
      zio.aws.sms.model.primitives.NonEmptyStringWithMaxLen255.Type
    object NumberOfRecentAmisToKeep extends Subtype[Int]
    type NumberOfRecentAmisToKeep =
      zio.aws.sms.model.primitives.NumberOfRecentAmisToKeep.Type
    object ReplicationJobId extends Subtype[String]
    type ReplicationJobId = zio.aws.sms.model.primitives.ReplicationJobId.Type
    object ReplicationJobStatusMessage extends Subtype[String]
    type ReplicationJobStatusMessage =
      zio.aws.sms.model.primitives.ReplicationJobStatusMessage.Type
    object ReplicationJobTerminated extends Subtype[Boolean]
    type ReplicationJobTerminated =
      zio.aws.sms.model.primitives.ReplicationJobTerminated.Type
    object ReplicationRunId extends Subtype[String]
    type ReplicationRunId = zio.aws.sms.model.primitives.ReplicationRunId.Type
    object ReplicationRunStage extends Subtype[String]
    type ReplicationRunStage =
      zio.aws.sms.model.primitives.ReplicationRunStage.Type
    object ReplicationRunStageProgress extends Subtype[String]
    type ReplicationRunStageProgress =
      zio.aws.sms.model.primitives.ReplicationRunStageProgress.Type
    object ReplicationRunStatusMessage extends Subtype[String]
    type ReplicationRunStatusMessage =
      zio.aws.sms.model.primitives.ReplicationRunStatusMessage.Type
    object RoleName extends Subtype[String]
    type RoleName = zio.aws.sms.model.primitives.RoleName.Type
    object RunOnce extends Subtype[Boolean]
    type RunOnce = zio.aws.sms.model.primitives.RunOnce.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName = zio.aws.sms.model.primitives.S3BucketName.Type
    object S3KeyName extends Subtype[String]
    type S3KeyName = zio.aws.sms.model.primitives.S3KeyName.Type
    object SecurityGroup extends Subtype[String]
    type SecurityGroup = zio.aws.sms.model.primitives.SecurityGroup.Type
    object ServerGroupId extends Subtype[String]
    type ServerGroupId = zio.aws.sms.model.primitives.ServerGroupId.Type
    object ServerGroupName extends Subtype[String]
    type ServerGroupName = zio.aws.sms.model.primitives.ServerGroupName.Type
    object ServerId extends Subtype[String]
    type ServerId = zio.aws.sms.model.primitives.ServerId.Type
    object StackId extends Subtype[String]
    type StackId = zio.aws.sms.model.primitives.StackId.Type
    object StackName extends Subtype[String]
    type StackName = zio.aws.sms.model.primitives.StackName.Type
    object Subnet extends Subtype[String]
    type Subnet = zio.aws.sms.model.primitives.Subnet.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.sms.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.sms.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sms.model.primitives.Timestamp.Type
    object TotalServerGroups extends Subtype[Int]
    type TotalServerGroups = zio.aws.sms.model.primitives.TotalServerGroups.Type
    object TotalServers extends Subtype[Int]
    type TotalServers = zio.aws.sms.model.primitives.TotalServers.Type
    object VPC extends Subtype[String]
    type VPC = zio.aws.sms.model.primitives.VPC.Type
    object ValidationId extends Subtype[String]
    type ValidationId = zio.aws.sms.model.primitives.ValidationId.Type
    object ValidationStatusMessage extends Subtype[String]
    type ValidationStatusMessage =
      zio.aws.sms.model.primitives.ValidationStatusMessage.Type
    object VmId extends Subtype[String]
    type VmId = zio.aws.sms.model.primitives.VmId.Type
    object VmManagerId extends Subtype[String]
    type VmManagerId = zio.aws.sms.model.primitives.VmManagerId.Type
    object VmManagerName extends Subtype[String]
    type VmManagerName = zio.aws.sms.model.primitives.VmManagerName.Type
    object VmName extends Subtype[String]
    type VmName = zio.aws.sms.model.primitives.VmName.Type
    object VmPath extends Subtype[String]
    type VmPath = zio.aws.sms.model.primitives.VmPath.Type
  }
  type AppIds = List[AppId]
  type AppValidationConfigurations =
    List[zio.aws.sms.model.AppValidationConfiguration]
  type Apps = List[zio.aws.sms.model.AppSummary]
  type ConnectorCapabilityList = List[zio.aws.sms.model.ConnectorCapability]
  type ConnectorList = List[zio.aws.sms.model.Connector]
  type ReplicationJobList = List[zio.aws.sms.model.ReplicationJob]
  type ReplicationRunList = List[zio.aws.sms.model.ReplicationRun]
  type ServerGroupLaunchConfigurations =
    List[zio.aws.sms.model.ServerGroupLaunchConfiguration]
  type ServerGroupReplicationConfigurations =
    List[zio.aws.sms.model.ServerGroupReplicationConfiguration]
  type ServerGroupValidationConfigurations =
    List[zio.aws.sms.model.ServerGroupValidationConfiguration]
  type ServerGroups = List[zio.aws.sms.model.ServerGroup]
  type ServerLaunchConfigurations =
    List[zio.aws.sms.model.ServerLaunchConfiguration]
  type ServerList = List[zio.aws.sms.model.Server]
  type ServerReplicationConfigurations =
    List[zio.aws.sms.model.ServerReplicationConfiguration]
  type ServerValidationConfigurations =
    List[zio.aws.sms.model.ServerValidationConfiguration]
  type Tags = List[zio.aws.sms.model.Tag]
  type ValidationOutputList = List[zio.aws.sms.model.ValidationOutput]
  type VmServerAddressList = List[zio.aws.sms.model.VmServerAddress]
}

==> zio-aws-sms_2.12-7.28.29.9-sources.jar: zio/aws/sms/model/package.scala <==
package zio.aws.sms
import zio.aws.sms.model.primitives.AppId
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sms.model.primitives.ValidationId.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmiId extends zio.prelude.Subtype[String]
    type AmiId = zio.aws.sms.model.primitives.AmiId.Type
    object AppDescription extends zio.prelude.Subtype[String]
    type AppDescription = zio.aws.sms.model.primitives.AppDescription.Type
    object AppId extends zio.prelude.Subtype[String]
    type AppId = zio.aws.sms.model.primitives.AppId.Type
    object AppIdWithValidation extends zio.prelude.Subtype[String]
    type AppIdWithValidation =
      zio.aws.sms.model.primitives.AppIdWithValidation.Type
    object AppLaunchStatusMessage extends zio.prelude.Subtype[String]
    type AppLaunchStatusMessage =
      zio.aws.sms.model.primitives.AppLaunchStatusMessage.Type
    object AppName extends zio.prelude.Subtype[String]
    type AppName = zio.aws.sms.model.primitives.AppName.Type
    object AppReplicationStatusMessage extends zio.prelude.Subtype[String]
    type AppReplicationStatusMessage =
      zio.aws.sms.model.primitives.AppReplicationStatusMessage.Type
    object AppStatusMessage extends zio.prelude.Subtype[String]
    type AppStatusMessage = zio.aws.sms.model.primitives.AppStatusMessage.Type
    object AssociatePublicIpAddress extends zio.prelude.Subtype[Boolean]
    type AssociatePublicIpAddress =
      zio.aws.sms.model.primitives.AssociatePublicIpAddress.Type
    object AutoLaunch extends zio.prelude.Subtype[Boolean]
    type AutoLaunch = zio.aws.sms.model.primitives.AutoLaunch.Type
    object BucketName extends zio.prelude.Subtype[String]
    type BucketName = zio.aws.sms.model.primitives.BucketName.Type
    object ClientToken extends zio.prelude.Subtype[String]
    type ClientToken = zio.aws.sms.model.primitives.ClientToken.Type
    object Command extends zio.prelude.Subtype[String]
    type Command = zio.aws.sms.model.primitives.Command.Type
    object ConnectorId extends zio.prelude.Subtype[String]
    type ConnectorId = zio.aws.sms.model.primitives.ConnectorId.Type
    object ConnectorVersion extends zio.prelude.Subtype[String]
    type ConnectorVersion = zio.aws.sms.model.primitives.ConnectorVersion.Type
    object Description extends zio.prelude.Subtype[String]
    type Description = zio.aws.sms.model.primitives.Description.Type
    object EC2KeyName extends zio.prelude.Subtype[String]
    type EC2KeyName = zio.aws.sms.model.primitives.EC2KeyName.Type
    object Encrypted extends zio.prelude.Subtype[Boolean]
    type Encrypted = zio.aws.sms.model.primitives.Encrypted.Type
    object ExecutionTimeoutSeconds extends zio.prelude.Subtype[Int]
    type ExecutionTimeoutSeconds =
      zio.aws.sms.model.primitives.ExecutionTimeoutSeconds.Type
    object ForceStopAppReplication extends zio.prelude.Subtype[Boolean]
    type ForceStopAppReplication =
      zio.aws.sms.model.primitives.ForceStopAppReplication.Type
    object ForceTerminateApp extends zio.prelude.Subtype[Boolean]
    type ForceTerminateApp = zio.aws.sms.model.primitives.ForceTerminateApp.Type
    object Frequency extends zio.prelude.Subtype[Int]
    type Frequency = zio.aws.sms.model.primitives.Frequency.Type
    object ImportedAppId extends zio.prelude.Subtype[String]
    type ImportedAppId = zio.aws.sms.model.primitives.ImportedAppId.Type
    object InstanceId extends zio.prelude.Subtype[String]
    type InstanceId = zio.aws.sms.model.primitives.InstanceId.Type
    object InstanceType extends zio.prelude.Subtype[String]
    type InstanceType = zio.aws.sms.model.primitives.InstanceType.Type
    object IpAddress extends zio.prelude.Subtype[String]
    type IpAddress = zio.aws.sms.model.primitives.IpAddress.Type
    object KmsKeyId extends zio.prelude.Subtype[String]
    type KmsKeyId = zio.aws.sms.model.primitives.KmsKeyId.Type
    object LaunchOrder extends zio.prelude.Subtype[Int]
    type LaunchOrder = zio.aws.sms.model.primitives.LaunchOrder.Type
    object LogicalId extends zio.prelude.Subtype[String]
    type LogicalId = zio.aws.sms.model.primitives.LogicalId.Type
    object MacAddress extends zio.prelude.Subtype[String]
    type MacAddress = zio.aws.sms.model.primitives.MacAddress.Type
    object MaxResults extends zio.prelude.Subtype[Int]
    type MaxResults = zio.aws.sms.model.primitives.MaxResults.Type
    object NextToken extends zio.prelude.Subtype[String]
    type NextToken = zio.aws.sms.model.primitives.NextToken.Type
    object NonEmptyStringWithMaxLen255 extends zio.prelude.Subtype[String]
    type NonEmptyStringWithMaxLen255 =
      zio.aws.sms.model.primitives.NonEmptyStringWithMaxLen255.Type
    object NumberOfRecentAmisToKeep extends zio.prelude.Subtype[Int]
    type NumberOfRecentAmisToKeep =
      zio.aws.sms.model.primitives.NumberOfRecentAmisToKeep.Type
    object ReplicationJobId extends zio.prelude.Subtype[String]
    type ReplicationJobId = zio.aws.sms.model.primitives.ReplicationJobId.Type
    object ReplicationJobStatusMessage extends zio.prelude.Subtype[String]
    type ReplicationJobStatusMessage =
      zio.aws.sms.model.primitives.ReplicationJobStatusMessage.Type
    object ReplicationJobTerminated extends zio.prelude.Subtype[Boolean]
    type ReplicationJobTerminated =
      zio.aws.sms.model.primitives.ReplicationJobTerminated.Type
    object ReplicationRunId extends zio.prelude.Subtype[String]
    type ReplicationRunId = zio.aws.sms.model.primitives.ReplicationRunId.Type
    object ReplicationRunStage extends zio.prelude.Subtype[String]
    type ReplicationRunStage =
      zio.aws.sms.model.primitives.ReplicationRunStage.Type
    object ReplicationRunStageProgress extends zio.prelude.Subtype[String]
    type ReplicationRunStageProgress =
      zio.aws.sms.model.primitives.ReplicationRunStageProgress.Type
    object ReplicationRunStatusMessage extends zio.prelude.Subtype[String]
    type ReplicationRunStatusMessage =
      zio.aws.sms.model.primitives.ReplicationRunStatusMessage.Type
    object RoleName extends zio.prelude.Subtype[String]
    type RoleName = zio.aws.sms.model.primitives.RoleName.Type
    object RunOnce extends zio.prelude.Subtype[Boolean]
    type RunOnce = zio.aws.sms.model.primitives.RunOnce.Type
    object S3BucketName extends zio.prelude.Subtype[String]
    type S3BucketName = zio.aws.sms.model.primitives.S3BucketName.Type
    object S3KeyName extends zio.prelude.Subtype[String]
    type S3KeyName = zio.aws.sms.model.primitives.S3KeyName.Type
    object SecurityGroup extends zio.prelude.Subtype[String]
    type SecurityGroup = zio.aws.sms.model.primitives.SecurityGroup.Type
    object ServerGroupId extends zio.prelude.Subtype[String]
    type ServerGroupId = zio.aws.sms.model.primitives.ServerGroupId.Type
    object ServerGroupName extends zio.prelude.Subtype[String]
    type ServerGroupName = zio.aws.sms.model.primitives.ServerGroupName.Type
    object ServerId extends zio.prelude.Subtype[String]
    type ServerId = zio.aws.sms.model.primitives.ServerId.Type
    object StackId extends zio.prelude.Subtype[String]
    type StackId = zio.aws.sms.model.primitives.StackId.Type
    object StackName extends zio.prelude.Subtype[String]
    type StackName = zio.aws.sms.model.primitives.StackName.Type
    object Subnet extends zio.prelude.Subtype[String]
    type Subnet = zio.aws.sms.model.primitives.Subnet.Type
    object TagKey extends zio.prelude.Subtype[String]
    type TagKey = zio.aws.sms.model.primitives.TagKey.Type
    object TagValue extends zio.prelude.Subtype[String]
    type TagValue = zio.aws.sms.model.primitives.TagValue.Type
    object Timestamp extends zio.prelude.Subtype[Instant]
    type Timestamp = zio.aws.sms.model.primitives.Timestamp.Type
    object TotalServerGroups extends zio.prelude.Subtype[Int]
    type TotalServerGroups = zio.aws.sms.model.primitives.TotalServerGroups.Type
    object TotalServers extends zio.prelude.Subtype[Int]
    type TotalServers = zio.aws.sms.model.primitives.TotalServers.Type
    object VPC extends zio.prelude.Subtype[String]
    type VPC = zio.aws.sms.model.primitives.VPC.Type
    object ValidationId extends zio.prelude.Subtype[String]
    type ValidationId = zio.aws.sms.model.primitives.ValidationId.Type
    object ValidationStatusMessage extends zio.prelude.Subtype[String]
    type ValidationStatusMessage =
      zio.aws.sms.model.primitives.ValidationStatusMessage.Type
    object VmId extends zio.prelude.Subtype[String]
    type VmId = zio.aws.sms.model.primitives.VmId.Type
    object VmManagerId extends zio.prelude.Subtype[String]
    type VmManagerId = zio.aws.sms.model.primitives.VmManagerId.Type
    object VmManagerName extends zio.prelude.Subtype[String]
    type VmManagerName = zio.aws.sms.model.primitives.VmManagerName.Type
    object VmName extends zio.prelude.Subtype[String]
    type VmName = zio.aws.sms.model.primitives.VmName.Type
    object VmPath extends zio.prelude.Subtype[String]
    type VmPath = zio.aws.sms.model.primitives.VmPath.Type
  }
  type AppIds = List[AppId]
  type AppValidationConfigurations =
    List[zio.aws.sms.model.AppValidationConfiguration]
  type Apps = List[zio.aws.sms.model.AppSummary]
  type ConnectorCapabilityList = List[zio.aws.sms.model.ConnectorCapability]
  type ConnectorList = List[zio.aws.sms.model.Connector]
  type ReplicationJobList = List[zio.aws.sms.model.ReplicationJob]
  type ReplicationRunList = List[zio.aws.sms.model.ReplicationRun]
  type ServerGroupLaunchConfigurations =
    List[zio.aws.sms.model.ServerGroupLaunchConfiguration]
  type ServerGroupReplicationConfigurations =
    List[zio.aws.sms.model.ServerGroupReplicationConfiguration]
  type ServerGroupValidationConfigurations =
    List[zio.aws.sms.model.ServerGroupValidationConfiguration]
  type ServerGroups = List[zio.aws.sms.model.ServerGroup]
  type ServerLaunchConfigurations =
    List[zio.aws.sms.model.ServerLaunchConfiguration]
  type ServerList = List[zio.aws.sms.model.Server]
  type ServerReplicationConfigurations =
    List[zio.aws.sms.model.ServerReplicationConfiguration]
  type ServerValidationConfigurations =
    List[zio.aws.sms.model.ServerValidationConfiguration]
  type Tags = List[zio.aws.sms.model.Tag]
  type ValidationOutputList = List[zio.aws.sms.model.ValidationOutput]
  type VmServerAddressList = List[zio.aws.sms.model.VmServerAddress]
}
